# PySICKTiM - A Python Library for the SICK TiM5xx

Introduction
------

This is a python library made to interact with the SICK TiM561 LiDAR sensor.


Prerequisites
------
    pyusb


## Installation

from [PyPI](https://pypi.org/project/pysicktim/)

    pip3 install pysicktim

from source:

    git clone https://github.com/ansarid/pysicktim
    cd pysicktim
    pip3 install -r requirements.txt
    python3 setup.py install
